@@ -35,6 +35,8 @@
 #include <KLocalizedString>
 #include <krunner/querymatch.h>
 
+static const QString s_copyToClipboardId = QStringLiteral("copyToClipboard");
+
 K_EXPORT_PLASMA_RUNNER(calculatorrunner, CalculatorRunner)
 
 CalculatorRunner::CalculatorRunner( QObject* parent, const QVariantList &args )
@@ -57,6 +59,8 @@ CalculatorRunner::CalculatorRunner( QObject* parent, const QVariantList &args )
     addSyntax(Plasma::RunnerSyntax(QStringLiteral(":q:"), description));
     addSyntax(Plasma::RunnerSyntax(QStringLiteral("=:q:"), description));
     addSyntax(Plasma::RunnerSyntax(QStringLiteral(":q:="), description));
+
+    addAction(s_copyToClipboardId, QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy to Clipboard"));
 }
 
 CalculatorRunner::~CalculatorRunner()
@@ -258,8 +262,7 @@ void CalculatorRunner::match(Plasma::RunnerContext &context)
     cmd.replace(QRegExp(QStringLiteral("([a-zA-Z]+)")), QStringLiteral("Math.\\1")); //needed for accessing math funktions like sin(),....
     #endif
 
-    bool isApproximate = false;
-    QString result = calculate(cmd, &isApproximate);
+    QString result = calculate(cmd);
     if (!result.isEmpty() && result != cmd) {
         if (toHex) {
             result = "0x" + QString::number(result.toInt(), 16).toUpper();
@@ -269,22 +272,19 @@ void CalculatorRunner::match(Plasma::RunnerContext &context)
         match.setType(Plasma::QueryMatch::InformationalMatch);
         match.setIconName(QStringLiteral("accessories-calculator"));
         match.setText(result);
-        if (isApproximate) {
-            match.setSubtext(i18nc("The result of the calculation is only an approximation", "Approximation"));
-        }
         match.setData(result);
         match.setId(term);
         context.addMatch(match);
     }
 }
 
-QString CalculatorRunner::calculate(const QString& term, bool *isApproximate)
+QString CalculatorRunner::calculate(const QString& term)
 {
     #ifdef ENABLE_QALCULATE
     QString result;
 
     try {
-        result = m_engine->evaluate(term, isApproximate);
+        result = m_engine->evaluate(term);
     } catch(std::exception& e) {
         qDebug() << "qalculate error: " << e.what();
     }
@@ -324,7 +324,7 @@ void CalculatorRunner::run(const Plasma::RunnerContext &context, const Plasma::Q
 {
     Q_UNUSED(context);
 #ifdef ENABLE_QALCULATE
-    if (match.selectedAction()) {
+    if (match.selectedAction() == action(s_copyToClipboardId)) {
         m_engine->copyToClipboard();
     }
 #else
@@ -336,13 +336,7 @@ QList<QAction *> CalculatorRunner::actionsForMatch(const Plasma::QueryMatch &mat
 {
     Q_UNUSED(match)
 
-    const QString copyToClipboard = QStringLiteral("copyToClipboard");
-
-    if (!action(copyToClipboard)) {
-        (addAction(copyToClipboard, QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy to Clipboard")));
-    }
-
-    return {action(copyToClipboard)};
+    return {action(s_copyToClipboardId)};
 }
 
 QMimeData * CalculatorRunner::mimeDataForMatch(const Plasma::QueryMatch &match)
