@@ -24,11 +24,13 @@
 #include <QHash>
 #include <QString>
 #include <QTimer>
+#include <QAbstractNativeEventFilter>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
 
-class ScreenPool : public QObject {
+class ScreenPool : public QObject, public QAbstractNativeEventFilter
+{
     Q_OBJECT
 
 public:
@@ -50,6 +52,9 @@ public:
     //all ids that are known, included screens not enabled at the moment
     QList <int> knownIds() const;
 
+protected:
+    bool nativeEventFilter(const QByteArray & eventType, void * message, long * result) Q_DECL_OVERRIDE;
+
 private:
     void save();
 
