@@ -113,10 +113,6 @@ public:
 
     QString defaultContainmentPlugin() const;
 
-
-protected:
-    bool eventFilter(QObject *watched, QEvent *event) override;
-
 public Q_SLOTS:
     /**
      * Request saving applicationConfig on disk, it's event compressed, not immediate
@@ -142,6 +138,7 @@ public Q_SLOTS:
     void showInteractiveKWinConsole();
     void loadKWinScriptInInteractiveConsole(const QString &script);
     void toggleActivityManager();
+    void toggleWidgetExplorer();    
     void evaluateScript(const QString &string);
     void activateLauncherMenu();
 
@@ -189,7 +186,6 @@ protected Q_SLOTS:
 private Q_SLOTS:
     void createWaitingPanels();
     void handleContainmentAdded(Plasma::Containment *c);
-    void toggleWidgetExplorer();
     void syncAppConfig();
     void checkActivities();
     void currentActivityChanged(const QString &newActivity);
@@ -210,8 +206,11 @@ private Q_SLOTS:
     void interactiveConsoleVisibilityChanged(bool visible);
     void screenRemoved(QScreen* screen);
 
+    void activateTaskManagerEntry(int index);
+
 private:
     void updateStruts();
+    void configurationChanged(const QString &path);
     bool isOutputRedundant(QScreen* screen) const;
     void reconsiderOutputs();
     QList<PanelView *> panelsForScreen(QScreen *screen) const;
@@ -225,6 +224,9 @@ private:
 
     void insertContainment(const QString &activity, int screenNum, Plasma::Containment *containment);
 
+    KSharedConfig::Ptr m_config;
+    QString m_configPath;
+
     ScreenPool *m_screenPool;
     QString m_shell;
     KActivities::Controller *m_activityController;
@@ -242,7 +244,6 @@ private:
     QSet<QScreen*> m_redundantOutputs;
     QList<KDeclarative::QmlObject *> m_alternativesObjects;
     KDeclarative::QmlObject *m_interactiveConsole;
-    int m_eventBase;
 
     QTimer m_waitingPanelsTimer;
     QTimer m_appConfigSyncTimer;
